@@ -1,6 +1,6 @@
 from .handler import Handler
 
 __all__ = ["Handler",
-           "[pems_consts]",
+           "pems_consts",
            "pems_types",
            "utils"]
\ No newline at end of file
